@@ -11,17 +11,21 @@
 
 #pragma once
 
-#include <gpgme++/key.h>
+#include "keyusage.h"
 
 #include "kleo_export.h"
 
-class QString;
 #include <QStringList>
+
+#include <gpgme++/key.h>
+
+class QString;
 class QDate;
 class QIcon;
 
 namespace GpgME
 {
+class Error;
 class Import;
 }
 
@@ -32,15 +36,37 @@ class KeyGroup;
 namespace Formatting
 {
 
-KLEO_EXPORT QString prettyNameAndEMail(int proto, const char *id, const char *name, const char *email, const char *comment);
-KLEO_EXPORT QString prettyNameAndEMail(int proto, const QString &id, const QString &name, const QString &email, const QString &comment);
+class KLEO_EXPORT IconProvider
+{
+public:
+    inline explicit IconProvider(KeyUsage::Flags requiredUsages)
+        : usage{requiredUsages}
+    {
+    }
+
+    QIcon icon(const GpgME::Key &key) const;
+    QIcon icon(const KeyGroup &group) const;
+
+private:
+    KeyUsage usage;
+};
+
+KLEO_EXPORT QIcon successIcon();
+KLEO_EXPORT QIcon infoIcon();
+KLEO_EXPORT QIcon questionIcon();
+KLEO_EXPORT QIcon unavailableIcon();
+KLEO_EXPORT QIcon warningIcon();
+KLEO_EXPORT QIcon errorIcon();
+
+KLEO_EXPORT QString prettyNameAndEMail(int proto, const char *id, const char *name, const char *email, const char *comment = nullptr);
+KLEO_EXPORT QString prettyNameAndEMail(int proto, const QString &id, const QString &name, const QString &email, const QString &comment = {});
 KLEO_EXPORT QString prettyNameAndEMail(const GpgME::Key &key);
 KLEO_EXPORT QString prettyNameAndEMail(const GpgME::UserID &key);
 
 KLEO_EXPORT QString prettyUserID(const GpgME::UserID &uid);
 KLEO_EXPORT QString prettyKeyID(const char *id);
 
-KLEO_EXPORT QString prettyName(int proto, const char *id, const char *name, const char *comment);
+KLEO_EXPORT QString prettyName(int proto, const char *id, const char *name, const char *comment = nullptr);
 KLEO_EXPORT QString prettyName(const GpgME::Key &key);
 KLEO_EXPORT QString prettyName(const GpgME::UserID &uid);
 KLEO_EXPORT QString prettyName(const GpgME::UserID::Signature &sig);
@@ -54,6 +80,7 @@ KLEO_EXPORT QString prettyEMail(const GpgME::UserID::Signature &sig);
 KLEO_EXPORT QString prettyID(const char *id);
 KLEO_EXPORT QString accessibleHexID(const char *id);
 
+// clang-format off
 enum ToolTipOption {
     KeyID            = 0x001,
     Validity         = 0x002,
@@ -69,19 +96,40 @@ enum ToolTipOption {
     OwnerTrust       = 0x800,
     Subkeys          = 0x1000,
 
-    AllOptions = 0xffff
+    AllOptions       = 0xffff
 };
+// clang-format on
 
 KLEO_EXPORT QString toolTip(const GpgME::Key &key, int opts);
 KLEO_EXPORT QString toolTip(const Kleo::KeyGroup &group, int opts);
 
-KLEO_EXPORT QString expirationDateString(const GpgME::Key &key);
-KLEO_EXPORT QString expirationDateString(const GpgME::Subkey &subkey);
-KLEO_EXPORT QString expirationDateString(const GpgME::UserID::Signature &sig);
+/// Returns expiration date of @p key as string, or @p noExpiration if the key doesn't expire.
+KLEO_EXPORT QString expirationDateString(const GpgME::Key &key, const QString &noExpiration = {});
+/// Returns expiration date of @p subkey as string, or @p noExpiration if the subkey doesn't expire.
+KLEO_EXPORT QString expirationDateString(const GpgME::Subkey &subkey, const QString &noExpiration = {});
+/// Returns expiration date of @p sig as string, or @p noExpiration if the signature doesn't expire.
+KLEO_EXPORT QString expirationDateString(const GpgME::UserID::Signature &sig, const QString &noExpiration = {});
 KLEO_EXPORT QDate expirationDate(const GpgME::Key &key);
 KLEO_EXPORT QDate expirationDate(const GpgME::Subkey &subkey);
 KLEO_EXPORT QDate expirationDate(const GpgME::UserID::Signature &sig);
-KLEO_EXPORT QString accessibleExpirationDate(const GpgME::Key &key);
+/**
+ * Returns expiration date of @p key as string suitable for screen readers.
+ * If the key doesn't expire, then it returns @p noExpiration if @p noExpiration is not empty. Otherwise,
+ * returns the localization of "unlimited".
+ */
+KLEO_EXPORT QString accessibleExpirationDate(const GpgME::Key &key, const QString &noExpiration = {});
+/**
+ * Returns expiration date of @p subkey as string suitable for screen readers.
+ * If the subkey doesn't expire, then it returns @p noExpiration if @p noExpiration is not empty. Otherwise,
+ * returns the localization of "unlimited".
+ */
+KLEO_EXPORT QString accessibleExpirationDate(const GpgME::Subkey &subkey, const QString &noExpiration = {});
+/**
+ * Returns expiration date of @p sig as string suitable for screen readers.
+ * If the signature doesn't expire, then it returns @p noExpiration if @p noExpiration is not empty. Otherwise,
+ * returns the localization of "unlimited".
+ */
+KLEO_EXPORT QString accessibleExpirationDate(const GpgME::UserID::Signature &sig, const QString &noExpiration = {});
 
 KLEO_EXPORT QString creationDateString(const GpgME::Key &key);
 KLEO_EXPORT QString creationDateString(const GpgME::Subkey &subkey);
@@ -90,10 +138,13 @@ KLEO_EXPORT QDate creationDate(const GpgME::Key &key);
 KLEO_EXPORT QDate creationDate(const GpgME::Subkey &subkey);
 KLEO_EXPORT QDate creationDate(const GpgME::UserID::Signature &sig);
 KLEO_EXPORT QString accessibleCreationDate(const GpgME::Key &key);
+KLEO_EXPORT QString accessibleCreationDate(const GpgME::Subkey &subkey);
 
-/* Convert a GPGME style time to a localized string */
+/* Convert a GPGME style time or a QDate to a localized string */
 KLEO_EXPORT QString dateString(time_t t);
+KLEO_EXPORT QString dateString(const QDate &date);
 KLEO_EXPORT QString accessibleDate(time_t t);
+KLEO_EXPORT QString accessibleDate(const QDate &date);
 
 KLEO_EXPORT QString displayName(GpgME::Protocol prot);
 KLEO_EXPORT QString type(const GpgME::Key &key);
@@ -106,7 +157,7 @@ KLEO_EXPORT QString ownerTrustShort(GpgME::Key::OwnerTrust trust);
 KLEO_EXPORT QString validityShort(const GpgME::Subkey &subkey);
 KLEO_EXPORT QString validityShort(const GpgME::UserID &uid);
 KLEO_EXPORT QString validityShort(const GpgME::UserID::Signature &sig);
-KLEO_EXPORT QIcon   validityIcon(const GpgME::UserID::Signature &sig);
+KLEO_EXPORT QIcon validityIcon(const GpgME::UserID::Signature &sig);
 /* A sentence about the validity of the UserID */
 KLEO_EXPORT QString validity(const GpgME::UserID &uid);
 KLEO_EXPORT QString validity(const Kleo::KeyGroup &group);
@@ -127,6 +178,7 @@ KLEO_EXPORT QString formatOverview(const GpgME::Key &key);
 KLEO_EXPORT QString usageString(const GpgME::Subkey &subkey);
 KLEO_EXPORT QString summaryLine(const GpgME::Key &key);
 KLEO_EXPORT QString summaryLine(const KeyGroup &group);
+KLEO_EXPORT QString nameAndEmailForSummaryLine(const GpgME::Key &key);
 
 KLEO_EXPORT QIcon iconForUid(const GpgME::UserID &uid);
 
@@ -141,14 +193,11 @@ KLEO_DEPRECATED_EXPORT QString complianceMode();
 
 /* Is the given key in compliance with CO_DE_VS?  */
 KLEO_EXPORT bool isKeyDeVs(const GpgME::Key &key);
-/* Localized string describing the name of the VS-NfD Compliance filter. If
- * compliant is false the name of the not Compliant filter.
- *
- * This is required to make the string configurable which is
- * a common request from users because VS-NfD compliance is called
- * differently in different environments. E.g NATO RESTRICTED or
- * EU RESTRICTED. */
-KLEO_EXPORT QString deVsString (bool compliant = true);
+
+/**
+ * Use Kleo::DeVSCompliance::name(bool) instead.
+ */
+KLEO_DEPRECATED_EXPORT QString deVsString(bool compliant = true);
 
 /* A sentence if the key confirms to the current compliance mode */
 KLEO_EXPORT QString complianceStringForKey(const GpgME::Key &key);
@@ -166,6 +215,10 @@ KLEO_EXPORT QString origin(int o);
 KLEO_EXPORT QString trustSignatureDomain(const GpgME::UserID::Signature &sig);
 /* Summary of trust signature properties */
 KLEO_EXPORT QString trustSignature(const GpgME::UserID::Signature &sig);
-}
-}
 
+/**
+ * Returns the value of Error::asString() for the error \p error as Unicode string.
+ */
+KLEO_EXPORT QString errorAsString(const GpgME::Error &error);
+}
+}
